# frozen_string_literal: true

# Custom URL definitions for the Community Edition.

draw 'directs/milestone'
draw_all 'directs/subscription_portal'
draw 'directs/promo'
